# Awesome Markdown [![Awesome](https://cdn.rawgit.com/sindresorhus/awesome/d7305f38d29fed78fa85652e3a63e154dd8e8829/media/badge.svg)](https://github.com/sindresorhus/awesome)

<img src="https://upload.wikimedia.org/wikipedia/commons/4/48/Markdown-mark.svg" align="right" width="208">

> A curated list of delightful Markdown stuff.

Markdown is a markup language created by John Gruber in collaboration with Aaron Swartz. It was designed to be easily converted to HTML and has been extended into different types of implementations.

<!--lint disable no-emphasis-as-heading-->

_Please read the [contribution guidelines](.github/contributing.md) before contributing._

<!--lint enable no-emphasis-as-heading-->

:gem: means **really _awesome/useful_**.<br />
![Globe][globe] means that **it's _webapp/webservice_**.<br />
![Android OS][android-os] means that **runs on _Android_**.<br />
![iOS Logo][ios-logo] means that **runs on _iOS_**.<br />
![Mac OS X][macosx] means that **runs on _macOS_**.<br />
![Linux][linux] means that **runs on _Linux_**.<br />
![Windows][windows] means that **runs on _Windows_**.<br />

<!--lint disable no-paragraph-content-indent-->

<!--lint disable alphabetize-lists-->

## Contents

- [CMS / Blogs](#cms--blogs)
- [Libraries](#libraries)
	- [C](#c)
	- [Java](#java)
	- [JavaScript](#javascript)
	- [Perl](#perl)
	- [PHP](#php)
	- [Python](#python)
	- [Ruby](#ruby)
- [Tools](#tools)
	- [Converters](#converters)
	- [Editors](#editors)
	- [Linters](#linters)
	- [Miscellaneous](#miscellaneous)
	- [Presentations](#presentations)
- [Services](#services)
- [Resources](#resources)
	- [Documentation](#documentation)
	- [Tutorials](#tutorials)

---

<!--lint enable alphabetize-lists-->

<!--lint enable no-paragraph-content-indent-->

## CMS / Blogs

> CMS or Blogs which support Markdown by default.

- [Ghost](https://blog.ghost.org/markdown/) - Publishing platform for professional bloggers.
- [Grav](https://getgrav.org/) - Modern Flat-File CMS.
- [Hexo](https://hexo.io/) - A fast, simple & powerful blog framework
- [Hugo](https://gohugo.io/) - Fast & Modern Static Website Engine.
- [Jekyll](https://jekyllrb.com/) - Transform your plain text into static websites and blogs.
- [Svbtle](https://svbtle.com/) - Blogging platform designed to help you think.
- [Vuepress](https://vuepress.vuejs.org/) - Minimalistic Vue-powered static site generator.

## Libraries

> Libraries for rendering Markdown documents.

### C

- [Hoedown](https://github.com/hoedown/hoedown) - Standards compliant, fast, secure Markdown processing library in C (Sundown fork).
- [peg-markdown](https://github.com/jgm/peg-markdown) - An implementation of Markdown in C, using a PEG grammar.
- [Sundown](https://github.com/vmg/sundown) - Standards compliant, fast, secure Markdown processing library in C.

### Java

- [commonmark-java](https://github.com/atlassian/commonmark-java) - Java implementation of CommonMark, a specification of the Markdown format.
- [flexmark-java](https://github.com/vsch/flexmark-java) - Java Implementation of Markdown parser with source level AST.
- [pegdown](https://github.com/sirthias/pegdown) - A pure-Java Markdown processor based on a parboiled PEG parser supporting a number of extensions.

### JavaScript

- [markdown-it](https://github.com/markdown-it/markdown-it) - Markdown parser, done right. 100% CommonMark support, extensions, syntax plugins & high speed.
- [markdown-js](https://github.com/evilstreak/markdown-js) - Yet another Markdown parser, this time for JavaScript.
- [marked](https://github.com/markedjs/marked) - Full-featured Markdown parser and compiler, written in JavaScript. Built for speed.
- [mmarkdown](https://github.com/albinotonnina/mmarkdown) - Interpret mmd fenced code blocks in a markdown file and generate a cooler version of it.
- [Showdown](https://github.com/showdownjs/showdown) - Showdown is a JavaScript Markdown to HTML converter, based on the original works by John Gruber.
- [Snarkdown](https://github.com/developit/snarkdown) - Snarkdown is a dead simple 1kb Markdown parser.

### Perl

- [Markdown.pl](https://daringfireball.net/projects/downloads/Markdown_1.0.1.zip) :gem: _John Gruber's original Markdown library._

### PHP

- [parsedown](https://github.com/erusev/parsedown) - Better Markdown Parser in PHP.
- [php-markdown](https://github.com/michelf/php-markdown) - Parser for Markdown and Markdown Extra derived from the original Markdown.pl by John Gruber.

### Python

- [markdown2](https://github.com/trentm/python-markdown2) - Fast and complete implementation of Markdown in Python.
- [Mistune](https://github.com/lepture/mistune) - The fastest Markdown parser in pure Python with renderer feature.
- [Python-Markdown](https://github.com/Python-Markdown/markdown) - Python implementation of John Gruber's Markdown.

### Ruby

- [kramdown](https://github.com/gettalong/kramdown) - kramdown is a fast, pure Ruby Markdown superset converter, using a strict syntax definition and supporting several common extensions.
- [Redcarpet](https://github.com/vmg/redcarpet) - Redcarpet is a Ruby library for Markdown processing that smells like butterflies and popcorn.

## Tools

### Converters

> Convert Markdown to other formats and vice versa.

- [csvtomd](https://github.com/mplewis/csvtomd) - Convert your CSV files into Markdown tables. ![Mac OS X][macosx] ![Linux][linux] ![Windows][windows]
- [Dimer Markdown](https://github.com/dimerapp/markdown) - converts Markdown to HTML or to JSON ![Globe][globe] ![Mac OS X][macosx] ![Linux][linux] ![Windows][windows]
- [HTML To Markdown for PHP](https://github.com/thephpleague/html-to-markdown) - Convert HTML to Markdown with PHP.
- [markdown-pdf](https://github.com/alanshaw/markdown-pdf) - Markdown to PDF converter.
- [Markdown to PDF](https://www.markdowntopdf.com/) - Simple and useful website for converting Markdown to PDF. ![Globe][globe]
- [Pandoc](http://pandoc.org/) - Universal document converter. ![Mac OS X][macosx] ![Linux][linux] ![Windows][windows]
- [Torsimany](https://github.com/PolBaladas/torsimany) - Translate format-independent JSON to stylish, human-readable Markdown. ![Mac OS X][macosx] ![Linux][linux] ![Windows][windows]
- [turndown](https://github.com/domchristie/turndown) - HTML to Markdown converter written in JavaScript.
- [yamp](https://github.com/angrykoala/yamp) - Easy-to-use cli toolbox for markdown-related task. ![Mac OS X][macosx] ![Linux][linux] ![Windows][windows]

### Editors

> Edit and save your Markdown documents.

- [Abricotine](http://abricotine.brrd.fr/) - Lightweight markdown editor built with Electron with built-in realtime preview. ![Mac OS X][macosx] ![Linux][linux] ![Windows][windows]
- [Caret](https://caret.io/) - Markdown Editor for Mac and PC. ![Mac OS X][macosx] ![Linux][linux] ![Windows][windows]
- [iA Writer](https://ia.net/writer) - iA Writer is designed to provide the best writing experience on Mac OS, iOS and Android. :gem: _Really simple editor!_ ![Android OS][android-os] ![iOS Logo][ios-logo] ![Mac OS X][macosx]
- [Markdownify](https://markdownify.js.org) - A minimal Markdown Editor desktop app. ![Mac OS X][macosx] ![Linux][linux] ![Windows][windows]
- [MarkRight](https://github.com/dvcrn/markright) - Minimalistic github flavored Markdown editor. ![Mac OS X][macosx] ![Linux][linux] ![Windows][windows]
- [Mark Text](https://github.com/marktext/marktext/) - Next generation Markdown editor (built with Electron). ![Mac OS X][macosx] ![Linux][linux] ![Windows][windows]
- [PileMd](https://pilemd.com/) - Markdown Note App. ![Mac OS X][macosx] ![Linux][linux] ![Windows][windows]
- [StackEdit](https://stackedit.io/) - In-browser markdown editor. ![Globe][globe]
- [TOAST UI Editor](https://ui.toast.com/tui-editor/) - Extensible GFM Markdown WYSIWYG Editor ![Globe][globe]
- [Typora](https://typora.io/) - A minimal Markdown editor. ![Mac OS X][macosx] ![Linux][linux] ![Windows][windows]

### Linters

> Flag and standarize your Markdown documents.

- [Markdown Lint Tool](https://github.com/markdownlint/markdownlint) - Tool to check Markdown files and flag style issues.
- [Markdownlint](https://github.com/igorshubovych/markdownlint-cli) - Node.js style checker and lint tool for Markdown/CommonMark files.
- [remark-lint](https://github.com/remarkjs/remark-lint) - Markdown code style linter.
- [textlint](https://textlint.github.io/) - Pluggable linting tool for text and markdown.

### Miscellaneous

> Tools which let you edit, convert, export, _et al._ your Markdown documents.

- [Classeur](http://classeur.io/) - Classeur is a new platform to write simple notes as well as technical documents and blogs. ![Globe][globe]
- [Dillinger](https://dillinger.io/) - Dillinger is a cloud-enabled, mobile-ready, offline-storage, AngularJS powered HTML5 Markdown editor. ![Globe][globe]
- [GitDown](https://github.com/gajus/gitdown) – GitHub's Markdown preprocessor. :octocat:
- [HackMD](https://hackmd.io) - HackMD lets you create realtime collaborative Markdown notes on all platforms. ![Globe][globe]
- [Laverna](https://laverna.cc/) - Laverna is a JavaScript note taking application with Markdown editor and encryption support. :gem: _Markdown notes with encryption!_ ![Globe][globe] ![Mac OS X][macosx] ![Linux][linux] ![Windows][windows]
- [Markable.in](https://markable.in/) - Remarkable Markdown Editor. ![Globe][globe]
- [markcat](https://github.com/BubuAnabelas/markcat) - Markdown files terminal viewer. :gem: _`cat` with Markdown highlight._ ![Mac OS X][macosx] ![Linux][linux] ![Windows][windows]
- [Markdown Tables Generator](http://www.tablesgenerator.com/markdown_tables) - Visual Markdown table builder with CSV importing support. ![Globe][globe]
- [remark](https://remark.js.org/) - Markdown processor powered by plugins
- [Socrates](http://socrates.io/) - Serveless realtime Markdown editor and viewer, etherpad-like. ![Globe][globe]
- [Markdown Magic](https://github.com/DavidWells/markdown-magic) - Automatically format markdown files and sync external docs/src code

### Presentations

> Create and edit your slides presentations with Markdown.

- [gitpitch](https://github.com/gitpitch/gitpitch/) - Markdown Presentations For Everyone on GitHub, GitLab, Bitbucket, GitBucket, Gitea, and Gogs. ![Globe][globe]
- [Marp](https://yhatt.github.io/marp/) - Markdown Presentation Writer. :gem: _Like PowerPoint but with Markdown!_ ![Mac OS X][macosx] ![Linux][linux] ![Windows][windows]
- [mdp](https://github.com/visit1985/mdp) - Command-line based Markdown presentation tool. :gem: _Like PowerPoint and Vim but with Markdown!_ ![Mac OS X][macosx] ![Linux][linux]
- [remark](https://remarkjs.com) - A simple, in-browser, Markdown-driven slideshow tool targeted at people who know their way around HTML and CSS. ![Globe][globe]

## Services

> Different services which take advantage of Markdown.

- [Daux.io](http://daux.io) - Daux.io is an documentation generator that uses a simple folder structure and Markdown files to create custom documentation on the fly.
- [Dimer](https://dimerapp.com/) - Dimer generates a clean and beautiful documentation website from Markdown. ![Globe][globe]
- [GitBook](https://www.gitbook.com/?t=1) - GitBook is a modern publishing toolchain. Making both writing and collaboration easy.
- [GitPrint](https://gitprint.com/) - Easily print GitHub Markdown. ![Globe][globe]

## Resources

### Documentation

> Documentation and useful information about Markdown.

- [CommonMark](https://commonmark.org/) - Strongly defined, highly compatible specification of Markdown.
- [GitHub Flavored Markdown Specifications](https://github.github.com/gfm/) - The formal spec for GitHub's Markdown, based on CommonMark.
- [Original Specifications](https://daringfireball.net/projects/markdown/) :gem: _The place to start with Markdown!_
- [Pandoc’s Markdown](http://pandoc.org/MANUAL.html#pandocs-markdown) - [Pandoc](http://pandoc.org/) has its own, powerful markdown implementation. It consists of several addional extensions.
- [ScholarlyMarkdown](http://scholarlymarkdown.com/) - ScholarlyMarkdown is a syntax/standard/best-practice of scholarly and academic communication that is web-first, semantic XML-second, and LaTeX/Word a close third.
- [Stack Overflow Markdown Documentation (archived)](https://web.archive.org/web/20160724152503/https://stackoverflow.com/documentation/markdown/topics) - Well organized Markdown documentation.
- [Stack Overflow Markdown Questions](https://stackoverflow.com/questions/tagged/markdown) - Highest voted Markdown questions on Stack Overflow.
- [The text/markdown Media Type (RFC7763)](https://tools.ietf.org/html/rfc7763) - This document registers the `text/markdown` media type for use with Markdown, a family of plain-text formatting syntaxes.
- [Wikipedia Article](https://en.wikipedia.org/wiki/Markdown)

### Tutorials

> Useful links and tutorials.

- [GitHub's Mastering Markdown](https://guides.github.com/features/mastering-markdown/)
- [how-to-markdown](https://github.com/workshopper/how-to-markdown) - This workshopper will teach you how to use Markdown.
- [Interactive Markdown Tutorial](https://www.markdowntutorial.com/)
- [Markdown Cheatsheet](https://github.com/adam-p/markdown-here/wiki/Markdown-Cheatsheet) :gem: _Where to look when you don't remember the syntax!_
- [Markdown Guide](https://www.markdownguide.org) - A concise, barebones guide to Markdown.

---

_[Icon pack by Icons8](https://icons8.com)_

## License

[![CC0](http://mirrors.creativecommons.org/presskit/buttons/88x31/svg/cc-zero.svg)](https://creativecommons.org/publicdomain/zero/1.0/)

To the extent possible under law, [Joaquín Serna](https://github.com/BubuAnabelas) has waived all copyright and related or neighboring rights to this work.

<!--Definitions-->

[globe]: https://maxcdn.icons8.com/Color/PNG/24/Maps/globe-24.png 'Globe'
[android-os]: https://maxcdn.icons8.com/Color/PNG/24/Operating_Systems/android_os_copyrighted-24.png 'Android OS'
[ios-logo]: https://maxcdn.icons8.com/Color/PNG/24/Logos/ios_logo-24.png 'iOS Logo'
[macosx]: https://maxcdn.icons8.com/Android_L/PNG/24/Operating_Systems/mac_os-24.png 'Mac OS X'
[linux]: https://maxcdn.icons8.com/Color/PNG/24/Operating_Systems/linux-24.png 'Linux'
[windows]: https://maxcdn.icons8.com/Color/PNG/24/Operating_Systems/windows8_copyrighted-24.png 'Windows'
